#
# spec file for package python-stevedore
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pypi_name stevedore
Name:           python-stevedore
Version:        1.17.1
Release:        3.3
Summary:        Manage dynamic plugins for Python applications
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://docs.openstack.org/developer/stevedore/
Source0:        https://tarballs.openstack.org/stevedore/%{pypi_name}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-setuptools >= 16.0
Requires:       python-pbr >= 1.6
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
Python makes loading code dynamically easy, allowing you to configure
and extend your application by discovering and loading extensions
(plugins) at runtime. Many applications implement their own
library for doing this, using ``__import__`` or ``importlib``.
stevedore avoids creating yet another extension
mechanism by building on top of setuptools entry points. The code
for managing entry points tends to be repetitive, though, so stevedore
provides manager classes for implementing common patterns for using
dynamically loaded extensions.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
Python makes loading code dynamically easy, allowing you to configure
and extend your application by discovering and loading extensions
(plugins) at runtime. Many applications implement their own
library for doing this, using ``__import__`` or ``importlib``.
stevedore avoids creating yet another extension
mechanism by building on top of setuptools entry points. The code
for managing entry points tends to be repetitive, though, so stevedore
provides manager classes for implementing common patterns for using
dynamically loaded extensions.

This package contains documentation in HTML format.

%prep
%setup -q -n %{pypi_name}-%{version}

%build
%py2_build

# generate html docs
%{__python2} setup.py build_sphinx
# remove the Sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}

%check
%{__python2} setup.py testr

%install
%py2_install

%files
%license LICENSE
%doc README.rst
%{python2_sitelib}/%{pypi_name}
%{python2_sitelib}/%{pypi_name}-*.egg-info

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Sun Oct  2 2016 dmueller@suse.com
- add source service to rpm-packaging and refresh
* Tue Aug 30 2016 tbechtold@suse.com
- update to 1.17.1:
  * do not emit warnings for missing hooks
  * Remove discover from test-requirements
  * make error reporting for extension loading quieter
  * Add Python 3.5 classifier and venv
  * Replace assertEquals() with assertEqual()
* Wed Jul 20 2016 tbechtold@suse.com
- update to 1.16.0:
  * Fix NamedExtensionManager fails when loading failing extension in order
  * Remove irrelated output item
  * Fix broken link about setuptools entry points
  * NamedExtensionManager: call a callback when some names cannot be found
  * Updated from global requirements
  * Trivial: ignore openstack/common in flake8 exclude list
  * dont claim copyright for future years
- Use pypi.io for Source url
* Thu Apr 21 2016 tbechtold@suse.com
- update to 1.12.0:
  * Add a reference to entry_point_inspector
  * Updated from global requirements
  * Trival:Remove unused logging import
  * Remove work around for NullHandler
  * remove unnecessary dependency on argparse
  * Use Stevedore exceptions for finding extensions
  * Clean up Python 2.6 related stuff
  * Updated from global requirements
  * Remove Python 2.6 classifier
  * cleanup tox.ini
  * Updated from global requirements
  * docs - Set pbr 'warnerrors' option for doc build
  * Add clarifying language to description of scanning for plugins
  * clean up default tox environment list
  * Show how to add a plugin in a separate package
  * replace the hard-coded history list with an auto-generated one
  * Fix spelling typo for maunal
  * Updated from global requirements
  * Examples typo fix
- Enable tests during build
* Wed Mar  9 2016 bwiedemann@suse.com
- use the year from changelog instead of current one
  to make reproducible rpms
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.8.0:
  * Updated from global requirements
* Mon Aug 31 2015 tbechtold@suse.com
- update to 1.7.0:
  * Updated from global requirements
  * Titlecase looks nicer sometimes in detailed mode
  * Update homepage to openstack hosted docs page
* Fri Jul 17 2015 tbechtold@suse.com
- update to 1.6.0:
  * Document the signature for check_func
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
  * Remove unnecessary openstack-common.conf
* Tue Jun 16 2015 tbechtold@suse.com
- update to 1.5.0:
  * Removed non-free color profile from .jpg
  * Add sphinx integration
  * Updated from global requirements
  * Fix Python versions supported
  * Remove run_cross_tests.sh
  * fix author contact details
  * re-raise exception with full traceback
  * Uncap library requirements for liberty
  * Add pypi download + version badges
  * Updated from global requirements
* Mon Mar 30 2015 tbechtold@suse.com
- update to 1.3.0:
  * Updated from global requirements
  * Fix test for finding multiple drivers
  * ignore .testrepository directory created by testr
  * clean up default environments run by tox
- Adjust Requires according to requirements.txt
* Tue Feb 24 2015 tbechtold@suse.com
- update to 1.2.0:
  * Use pkg_resources resolve(
  * Fix the README.rst file format for pypi
  * Workflow documentation is now in infra-manual
  * Implement a __contains__ override for extension manager
  * Update link to docs in README
  * Bring doc build up to standard
* Tue Oct 28 2014 dmueller@suse.com
- update to 1.1.0:
  * Add pbr to dependency list
  * Updated from global requirements
  * Add more detail to the README
  * Migrate tox to use testr
  * Update repository location in docs
* Tue Sep 23 2014 dmueller@suse.com
- add python-argparse dependency
* Sun Sep 21 2014 tbechtold@suse.com
- Add missing python-six Requires
* Fri Sep 19 2014 dmueller@suse.com
- update to 1.0:
  * Updated from global requirements
  * Fix incorrect image reference in documentation
  * Fix requirement handling in tox
  * Updated from global requirements
  * use six.add_metaclass
  * Updated from global requirements
  * driver: raise by default on import failure
  * Add doc requirements to venv environ
  * Import run_cross_tests.sh from oslo-incubator
  * fix link to entry point docs
* Fri Mar 28 2014 speilicke@suse.com
- Update to version 0.15:
  * Only log error when no load handler is set
  * Update readme with links to bug tracker and source
  * Update .gitreview after moving the repository
* Thu Feb 13 2014 speilicke@suse.com
- Update to version 0.14.1:
  + Fix the test manager implementation
- Changes from version 0.14.0t
  + Make requirements checking optional
  + Update docstrings
  + Allow a on_load_failure_callback to be provided
  + deprecate TestExtensionManager
* Mon Dec  2 2013 dmueller@suse.com
- update to 0.13:
  * Update documentation to refer to setuptools instead of distribute.
  * Add pypy to the list of default test configurations.
  * Include a work-around to avoid a cpython bug with atexit
  * Deprecate TestExtensionManager and replace with make_test_instance()
  class method to provide test classes that behave more like the
  production class, while still allowing the extensions to be injected
  for testing
  * Fixes an exception when reporting on an error where multiple
  drivers have the same name
  * Switch packaging to use pbr.
* Mon Sep  2 2013 dmueller@suse.com
- update to 0.11:
  * Fixes logging configuration under Python 2.6 with a NullHandler
* Thu Jul 11 2013 dmueller@suse.com
- update to 0.10:
  - Adds ``propagate_map_exceptions`` parameter to all of the extension
  managers which specifies whether exceptions are propagated up
  through the map call or logged and then ignored. The default is to
  preserve the current behavior of logging and ignoring exceptions.
- remove python-2.6.x.diff
* Fri Jun 21 2013 dmueller@suse.com
- add python-2.6.x.diff:
  * fix build on python 2.6
* Mon Jun 17 2013 speilicke@suse.com
- Update to version 0.9.1:
  + Add name_order parameter to NamedExtensionManager to coerce map() into
    processing the extensions in the order they are named when the manager is
    created, instead of the random order they may have been loaded.
  + Change the NamedDispatchExtensionManager to ignore missing extensions
    (issue 14).
  + Add __getitem__ to ExtensionManager for looking up individual plugins by
    name (issue 15).
  + Start working on the tutorial, Using Stevedore in Your Application.
- Drop semantic versioning hack
- Build HTML documentation
* Wed May 29 2013 dmueller@suse.com
- add compatibility provides of 0.8.0 version
  * needed for other packages that generate the version from
  * PyPi (where this is fetched when fetching 0.8.0)
* Sat Jan  5 2013 alexandre@exatati.com.br
- Update to 0.8:
  - Ignore AssertionError exceptions generated when plugins are
    loaded.
  - Update :class:`~stevedore.named.NamedExtensionManager` to check
    the name of a plugin before loading its code to avoid importing
    anything we are not going to use.
* Tue Dec  4 2012 alexandre@exatati.com.br
- Update to 0.7.2:
  - Fix logging support for Python 2.6.
- Aditional changes from 0.7.1:
  - Fix an issue with logging configuration.
- Aditional changes from 0.7:
  - Add memoization to the entrypoint scanning code in
    stevedore.extension.ExtensionManager to avoid performance issues
    in situations where lots of managers are instantiated with the
    same namespace argument.
* Wed Nov 21 2012 saschpe@suse.de
- Install LICENSE, README.rst and HTML documentation
* Mon Oct 29 2012 alexandre@exatati.com.br
- Update to 0.6:
  - Change the stevedore.enabled.EnabledExtensionManager to load
    the extension before calling the check function so the plugin
    can be asked if it should be enabled.
- Aditional changes from 0.5:
  - Add stevedore.tests.manager.TestExtensionManager for writing
    tests for classes that use extension managers.
* Sun Sep 16 2012 alexandre@exatati.com.br
- Update to 0.4:
  - Removed the name argument to plugin constructors.
  - Added driver property to stevedore.driver.DriverManager.
* Sun Aug 19 2012 alexandre@exatati.com.br
- Initial package (0.3) for openSUSE.
